/*
  File name        : rdtsc.h
  Date of creation : 26/1/2012
  Version          : 1.0
  Copyright        : Soft'n'design
  Author           : Laurent Mazet <mazet@softndesign.org>

  Description      : This file contains rdtsc inline function

  History          :
  - initial version
*/

#ifndef __RDTSC_H__
#define __RDTSC_H__

#include <stdint.h>
#include <sys/cdefs.h>

__BEGIN_DECLS

/**
    Get RDTSC counter

    @return counter
*/
#ifdef __i386
static __inline__ int64_t rdtsc (void) {
     int64_t x;
     __asm__ volatile ("rdtsc" : "=A" (x));
     return x;
}
#elif __amd64
static __inline__ int64_t rdtsc (void) {
     int64_t a, d;
     __asm__ volatile ("rdtsc" : "=a" (a), "=d" (d));
     return (d << 32) | a;
}
#endif

__END_DECLS

#endif /* __RDTSC_H__ */

/* vi:set tabstop=4 expandtab shiftwidth=4: this line set vi mode */
